
Snek is a project generator for bootstrapping high-quality Python packages,
ready to be shared on PyPI_ and installable via pip_. It is easy to use and
encourages the adoption of the best tools and practices of the Python
ecosystem, helping you and your team to stay sane, happy and productive.

It was branched from PyScaffold to remove the branding so I didn't have to
delete it from every new project I made.

Contents
--------

.. toctree::
   :maxdepth: 2

   Installation <install>
   Features <features>
   Usage & Examples <usage>
   Advanced Usage & Features <advanced>
   FAQ <faq>

.. toctree::
   :caption: Project
   :maxdepth: 2

   Contributions & Help <contributing>
   Developer Guide <dev-guide>
   Contributors <contributors>
   Changelog <changelog>
   License <license>
   Module Reference <api/modules>


Indices and tables
------------------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`


.. _PyPI: https://pypi.org/
.. _pip: https://pip.pypa.io/en/stable/
